@@ -5,7 +5,7 @@ import re
 from urllib.parse import urljoin
 
 import requests
-from hydbedscraper.requesters.common import decode_streamed_string_response
+from hydbedscraper.requesters._common import decode_streamed_string_response
 from hydbedscraper.types import t_TableList
 
 base_URL = "https://ahna.org.in/"
@@ -46,6 +46,7 @@ def get_hospital_tables() -> t_TableList:
     tables = camelot.read_pdf(
         urljoin(base_URL, pdf_url_suffix),
         pages="all",
+        line_scale=40,  # necessary to detect smaller tables
     )
 
     logging.info("..done")
